import curses
import sys


class Map:
    def __init__(self):
        self.map = [
        "####################",
        "###....#############",
        "###....#############",
        "###...........######",
        "#############.######",
        "#############....###",
        "#############....###",
        "####################"]

    def move_player(self, player, target_y, target_x):
        if self.map[target_y - 1][target_x - 1] != '#':
            player.y = target_y
            player.x = target_x

    def draw(self, win):
        map_line = 1
        for line in self.map:
            win.addstr(map_line, 1, line)
            map_line += 1

class UI:
    def __init__(self, stdscr, height, width, status_height):
        curses.curs_set(0)
        stdscr.clear()
        begin_x = 0
        begin_y = 0

        win = curses.newwin(height, width, begin_y, begin_x)
        win.keypad(True)
        status = win.subwin(status_height, width-2, height-status_height, begin_x+1)

        # keep these for later by assigning to self
        self.begin_x = 0
        self.begin_y = 0
        self.map = None
        self.height = height
        self.width = width
        self.win = win
        self.status = status
        self.status_height = status_height

    def set_map(self, the_map):
        self.map = the_map

    def update(self, player):
        assert self.map, "You forgot to call set_map()"
        self.win.clear()
        self.win.box()
        self.status.hline(0,0, curses.ACS_HLINE, self.width - 2)
        self.map.draw(self.win)
        self.draw_status()
        self.draw_player(player)
        self.win.refresh()

    def draw_status(self):
        self.status.addstr(1, 1, "PLAYER STATS")

    def draw_player(self, player):
        self.win.addstr(player.y, player.x, '@', curses.A_BOLD)

    def handle_input(self, y, x):
        ch = self.win.getch()

        if ch == ord('q'):
            sys.exit(0)
        elif ch == curses.KEY_UP:
            y = (y - 1) % self.height
        elif ch == curses.KEY_DOWN:
            y = (y + 1) % self.height
        elif ch == curses.KEY_RIGHT:
            x = (x + 1) % self.width
        elif ch == curses.KEY_LEFT:
            x = (x - 1) % self.width

        return y, x

class Player:
    def __init__(self, x, y):
        self.x = x
        self.y = y

class GameEngine:
    def __init__(self, ui):
        self.ui = ui
        self.player = Player(4, 4)
        self.map = Map()
        self.ui = ui
        ui.set_map(self.map)

    def run(self):
        while True:
            self.ui.update(self.player)
            new_y, new_x = self.ui.handle_input(self.player.y, self.player.x)
            self.map.move_player(self.player, new_y, new_x)

def main(stdscr):
    width=80
    height=26
    ui = UI(stdscr, height, width, 5)
    game = GameEngine(ui)
    game.run()

curses.wrapper(main)
