import curses
import sys

MAP = [
"####################",
"###....#############",
"###....#############",
"###...........######",
"#############.######",
"#############....###",
"#############....###",
"####################"]

class UI:
    def __init__(self, stdscr, height, width, status_height):
        curses.curs_set(0)
        stdscr.clear()
        begin_x = 0
        begin_y = 0

        win = curses.newwin(height, width, begin_y, begin_x)
        win.keypad(True)
        status = win.subwin(status_height, width-2, height-status_height, begin_x+1)

        # keep these for later by assigning to self
        self.begin_x = 0
        self.begin_y = 0
        self.height = height
        self.width = width
        self.win = win
        self.status = status
        self.status_height = status_height

    def update(self, player_y, player_x):
        self.win.clear()
        self.win.box()
        self.status.hline(0,0, curses.ACS_HLINE, self.width - 2)
        self.draw_map()
        self.draw_status()
        self.draw_player(player_y, player_x)
        self.win.refresh()

    def draw_map(self):
        map_line = 1
        for line in MAP:
            self.win.addstr(map_line, 1, line)
            map_line += 1

    def draw_status(self):
        self.status.addstr(1, 1, "PLAYER STATS")

    def draw_player(self, player_y, player_x):
        self.win.addstr(player_y, player_x, '@', curses.A_BOLD)

    def handle_input(self, y, x):
        ch = self.win.getch()

        if ch == ord('q'):
            sys.exit(0)
        elif ch == curses.KEY_UP:
            y = (y - 1) % self.height
        elif ch == curses.KEY_DOWN:
            y = (y + 1) % self.height
        elif ch == curses.KEY_RIGHT:
            x = (x + 1) % self.width
        elif ch == curses.KEY_LEFT:
            x = (x - 1) % self.width

        return y, x

def move_player(player_y, player_x, target_y, target_x):
    if MAP[target_y - 1][target_x - 1] != '#':
        return target_y, target_x
    else:
        return player_y, player_x

def main(stdscr):
    width=80
    height=26
    ui = UI(stdscr, height, width, 5)

    player_x = 4
    player_y = 4

    while True:
        ui.update(player_y, player_x)
        new_y, new_x = ui.handle_input(player_y, player_x)
        player_y, player_x = move_player(player_y, player_x, new_y, new_x)

curses.wrapper(main)
